#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-28ikUP3ZDJu2QMf7V4dSaG
key:                  misfortune-0.1.2.1-28ikUP3ZDJu2QMf7V4dSaG
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  040f8914c0783bf09e3143741af1dd6e
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-28ikUP3ZDJu2QMf7V4dSaG
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK directory-1.3.8.5
    filepath-1.4.300.1 knob-0.2.2-C6uO4qMQKGWIGLfyGFLrbG
    random-1.2.1.3-9HnDVtmtwMCAuyzxGkvhji
    random-fu-0.3.0.1-GqiQw0hjiX7AyZqQlzM0AY text-2.0.2
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-7BVLr4DYOHu1u41KuR5SBY

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

